@@ -18,11 +18,14 @@ def add_references_to_communication(comm):
     This function adds reference variables for:
     - a 'tokenization' to each TokenRefSequence
     - a 'entityMention' to each Argument
+    - a 'sentence' backpointer to each Tokenization
+    - a 'parentMention' backpointer to appropriate EntityMention
 
     And adds lists of reference variables for:
     - a 'mentionList' to each Entity
     - a 'situationMention' to each Argument
     - a 'mentionList' to each Situation
+    - a 'childMentionList' to each EntityMention
 
     For variables that represent optional lists of UUIDs
     (e.g. situation.mentionIdList), Python Thrift will set the
@@ -50,12 +53,22 @@ def add_references_to_communication(comm):
                     comm.sentenceForUUID[sentence.uuid.uuidString]= sentence
                     if sentence.tokenization:
                         comm.tokenizationForUUID[sentence.tokenization.uuid.uuidString] = sentence.tokenization
+                        sentence.tokenization.sentence = sentence
 
     if comm.entityMentionSetList:
         for entityMentionSet in comm.entityMentionSetList:
             for entityMention in entityMentionSet.mentionList:
                 comm.entityMentionForUUID[entityMention.uuid.uuidString] = entityMention
                 entityMention.tokens.tokenization = comm.tokenizationForUUID[entityMention.tokens.tokenizationId.uuidString]
+                # childMentionList and parentMention are in-memory references, and not part of the Concrete schema
+                entityMention.childMentionList = []
+                entityMention.parentMention = None
+            for entityMention in entityMentionSet.mentionList:
+                if entityMention.childMentionIdList:
+                    for childMentionId in entityMention.childMentionIdList:
+                        childMention = comm.entityMentionForUUID[childMentionId.uuidString]
+                        childMention.parentMention = entityMention
+                        entityMention.childMentionList.append(childMention)
 
     if comm.entitySetList:
         for entitySet in comm.entitySetList:
